/*******************************************************************************
* File Name: SEG_C.c  
* Version 2.20
*
* Description:
*  This file contains APIs to set up the Pins component for low power modes.
*
* Note:
*
********************************************************************************
* Copyright 2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#include "cytypes.h"
#include "SEG_C.h"

static SEG_C_BACKUP_STRUCT  SEG_C_backup = {0u, 0u, 0u};


/*******************************************************************************
* Function Name: SEG_C_Sleep
****************************************************************************//**
*
* \brief Stores the pin configuration and prepares the pin for entering chip 
*  deep-sleep/hibernate modes. This function applies only to SIO and USBIO pins.
*  It should not be called for GPIO or GPIO_OVT pins.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None 
*  
* \sideeffect
*  For SIO pins, this function configures the pin input threshold to CMOS and
*  drive level to Vddio. This is needed for SIO pins when in device 
*  deep-sleep/hibernate modes.
*
* \funcusage
*  \snippet SEG_C_SUT.c usage_SEG_C_Sleep_Wakeup
*******************************************************************************/
void SEG_C_Sleep(void)
{
    #if defined(SEG_C__PC)
        SEG_C_backup.pcState = SEG_C_PC;
    #else
        #if (CY_PSOC4_4200L)
            /* Save the regulator state and put the PHY into suspend mode */
            SEG_C_backup.usbState = SEG_C_CR1_REG;
            SEG_C_USB_POWER_REG |= SEG_C_USBIO_ENTER_SLEEP;
            SEG_C_CR1_REG &= SEG_C_USBIO_CR1_OFF;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(SEG_C__SIO)
        SEG_C_backup.sioState = SEG_C_SIO_REG;
        /* SIO requires unregulated output buffer and single ended input buffer */
        SEG_C_SIO_REG &= (uint32)(~SEG_C_SIO_LPM_MASK);
    #endif  
}


/*******************************************************************************
* Function Name: SEG_C_Wakeup
****************************************************************************//**
*
* \brief Restores the pin configuration that was saved during Pin_Sleep(). This 
* function applies only to SIO and USBIO pins. It should not be called for
* GPIO or GPIO_OVT pins.
*
* For USBIO pins, the wakeup is only triggered for falling edge interrupts.
*
* <b>Note</b> This function is available in PSoC 4 only.
*
* \return 
*  None
*  
* \funcusage
*  Refer to SEG_C_Sleep() for an example usage.
*******************************************************************************/
void SEG_C_Wakeup(void)
{
    #if defined(SEG_C__PC)
        SEG_C_PC = SEG_C_backup.pcState;
    #else
        #if (CY_PSOC4_4200L)
            /* Restore the regulator state and come out of suspend mode */
            SEG_C_USB_POWER_REG &= SEG_C_USBIO_EXIT_SLEEP_PH1;
            SEG_C_CR1_REG = SEG_C_backup.usbState;
            SEG_C_USB_POWER_REG &= SEG_C_USBIO_EXIT_SLEEP_PH2;
        #endif
    #endif
    #if defined(CYIPBLOCK_m0s8ioss_VERSION) && defined(SEG_C__SIO)
        SEG_C_SIO_REG = SEG_C_backup.sioState;
    #endif
}


/* [] END OF FILE */
